API Reference
=============

FixturesManager
---------------

.. autoclass:: charlatan.FixturesManager
    :members:


FixturesManagerMixin
--------------------

.. autoclass:: charlatan.FixturesManagerMixin
    :members:


Fixture
-------

.. autoclass:: charlatan.Fixture
    :members:


Utils
-----

.. automodule:: charlatan.utils
    :members:
